@@ -15,6 +15,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
+#include <ctime>
 #include "BPGame.h"
 #include "SDL.h"
 
@@ -22,7 +23,8 @@
 #include <GLES/gl.h>
 
 #include "SDL_ttf.h" 
-#include <string.h>
+#include <string>
+
 
 #include "bombhunt.h"
 #include "balloonblaster.h"
@@ -142,7 +144,7 @@ void BPGame::Init(int width, int height) {
 	TestBrainJobs.Add("Police Officer");
 	TestBrainJobs.Add("Meteorologist");
 	TestBrainJobs.Add("Art Valuer");
-	TestBrainJobs.Add("Musuem Curator");
+	TestBrainJobs.Add("Museum Curator");
 	TestBrainJobs.Add("Marine Biologist");
 	TestBrainJobs.Add("School Teacher");
 	TestBrainJobs.Add("Dentist");
@@ -783,7 +785,7 @@ void BPGame::Draw() {
 	}
 	
 	if (ShowingMessageBox) {
-		FillRectangle(Colour(0.0f, 0.0f, 0.0f, 0.85f), Rectangle(0, 0, 320, 480));
+		FillRectangle(Colour(0.0f, 0.0f, 0.0f, 0.85f), 0, 0, 320, 480);
 		
 		Colour col = Colour(1.0f, 1.0f, 1.0f, 1.0f);
 		sfcLogo->Draw(160, 90, 0.0f, 0.6f, col);
@@ -815,9 +817,9 @@ void BPGame::AddTestScore(int score) {
 	}
 }
 
-void BPGame::FillRectangle(Colour col, Rectangle rect) {
+void BPGame::FillRectangle(Colour col, float x, float y, float width, float height) {
 	glColor4f(col.R, col.G, col.B, col.A);
-	sfcWhite->Draw(rect.X, rect.Y, rect.Width, rect.Height);
+	sfcWhite->Draw(x, y, width, height);
 	glColor4f(1.0f, 1.0f, 1.0f, 1.0f);
 }
 
@@ -1233,6 +1235,7 @@ void BPGame::AllocString(SpriteFont** tex, const char* str, FontSizes size, floa
 	// do the last line too
 	string strSub = temp.substr(0, p);
 	lines.push_back(strSub);
+	
 		
 	// create a SpriteFont to hold all the information - this is used for drawing later
 	(*tex) = new SpriteFont();
@@ -1245,7 +1248,7 @@ void BPGame::AllocString(SpriteFont** tex, const char* str, FontSizes size, floa
 		SDL_Surface* sfc = TTF_RenderText_Blended(fnt, TrimString(lines[i]).c_str(), white);
 		
 		if (sfc != NULL) {
-			(*tex)->Surfaces.push_back(new Texture(sfc));
+			(*tex)->Surfaces.Add(new Texture(sfc));
 			SDL_FreeSurface(sfc);
 		}
 	}
